==> internetavailabilitychecker-1.0.2-sources.jar: com/treebo/internetavailabilitychecker/NetworkChangeReceiver.java <==
/*
 *Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.treebo.internetavailabilitychecker;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;

import java.lang.ref.WeakReference;

/**
 * Created by aa on 29/04/17.
 */

class NetworkChangeReceiver extends BroadcastReceiver {

    private static final String INET_CONDITION = "inetCondition";

    private WeakReference<NetworkChangeListener> mNetworkChangeListenerWeakReference;

    @Override
    public void onReceive(Context context, Intent intent) {
        Bundle bundle = intent.getExtras();
        int condition = 0;
        if (bundle != null) {
            condition = bundle.getInt(INET_CONDITION, 0);
        }
        NetworkChangeListener networkChangeListener = mNetworkChangeListenerWeakReference.get();
        if (networkChangeListener != null) {
            boolean isConnected = isNetworkConnected(context);
            if (isConnected) {
                if (condition > 0) {
                    networkChangeListener.onNetworkChange(true);
                }
            } else {
                networkChangeListener.onNetworkChange(false);
            }
        }
    }

    void setNetworkChangeListener(NetworkChangeListener networkChangeListener) {
        mNetworkChangeListenerWeakReference = new WeakReference<>(networkChangeListener);
    }

    void removeNetworkChangeListener() {
        if (mNetworkChangeListenerWeakReference != null) {
            mNetworkChangeListenerWeakReference.clear();
        }
    }

    boolean isNetworkConnected(Context context) {
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo netInfo = connectivityManager.getActiveNetworkInfo();

        //should check null because in airplane mode it will be null
        return netInfo != null && netInfo.isAvailable() && netInfo.isConnected();

    }

    //Interface to send opt to listeners
    interface NetworkChangeListener {
        void onNetworkChange(boolean isNetworkAvailable);
    }
}

==> internetavailabilitychecker-1.0.5-sources.jar: com/treebo/internetavailabilitychecker/NetworkChangeReceiver.java <==
/*
 *Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.treebo.internetavailabilitychecker;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;

import java.lang.ref.WeakReference;

/**
 * Created by aa on 29/04/17.
 */

class NetworkChangeReceiver extends BroadcastReceiver {

    private WeakReference<NetworkChangeListener> mNetworkChangeListenerWeakReference;

    @Override
    public void onReceive(Context context, Intent intent) {
        NetworkChangeListener networkChangeListener = mNetworkChangeListenerWeakReference.get();
        if (networkChangeListener != null) {
            boolean isConnected = isNetworkConnected(context);
            networkChangeListener.onNetworkChange(isConnected);
        }
    }

    void setNetworkChangeListener(NetworkChangeListener networkChangeListener) {
        mNetworkChangeListenerWeakReference = new WeakReference<>(networkChangeListener);
    }

    void removeNetworkChangeListener() {
        if (mNetworkChangeListenerWeakReference != null) {
            mNetworkChangeListenerWeakReference.clear();
        }
    }

    boolean isNetworkConnected(Context context) {
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo netInfo = connectivityManager.getActiveNetworkInfo();

        //should check null because in airplane mode it will be null
        return netInfo != null && netInfo.isAvailable() && netInfo.isConnected();

    }

    //Interface to send opt to listeners
    interface NetworkChangeListener {
        void onNetworkChange(boolean isNetworkAvailable);
    }
}
